Learn R Programming

bayesDccGarch (version 3.0.4)

logLikDccGarch: The logarithm of likelihood function of DCC-GARCH(1,1) Model.

Description

Compute the logarithm of likelihood function of DCC-GARCH(1,1) Model if mY is a matrix or the logarithm of likelihood function of GARCH(1,1) Model if mY is numeric vector.

Usage

logLikDccGarch(mY, omega = rep(0.03, ncol(mY)), alpha = rep(0.03, ncol(mY)), 
	beta = rep(0.8, ncol(mY)), a = 0.03, b = 0.8, gamma = rep(1, ncol(mY)), 
	tail = 10, errorDist = 2)

Value

Return a list with the elements:

$H

a matrix where the lines are the \(H_t\) values for t=1,...,n.

$value

the value of the logarithm of likelihood function.

Arguments

mY

a matrix of the data (\(n \times k\)).

omega

a numeric vector (\(k \times 1\)) with the the values of \(\omega_i\) parameters. Default: rep(0.03, ncol(mY)).

alpha

a numeric vector (\(k \times 1\)) with the the values of \(\alpha_i\) parameters. Default: rep(0.03, ncol(mY)).

beta

a numeric vector (\(k \times 1\)) with the the values of \(\beta_i\) parameters. Default: rep(0.80, ncol(mY)).

a

a numeric value of the \(a\) parameter. Default: 0.03.

b

a numeric value of the \(b\) parameter. Default: 0.8.

gamma

a numeric vector (\(k \times 1\)) with the values of \(\gamma_i\) parameters. Default: rep(1.0, ncol(mY)).

tail

a numeric value of \(\nu\) parameter if errorDist = 2 or of \(\delta\) parameter if errorDist = 3. If errorDist = 1 so this arguments is no used.

errorDist

a probability distribution for errors. Use errorDist=1 for \(SSNorm\), errorDist=2 for \(SST\) or errorDist=3 for \(SSGED\). Default: 2.

Author

Jose Augusto Fiorucci, Ricardo Sandes Ehlers and Francisco Louzada

Details

The log-likelihood of the model GARCH(1,1) is computed if mY has just one column. The arguments a and b are not consider in this case.

References

Fioruci, J.A., Ehlers, R.S., Andrade Filho, M.G. Bayesian multivariate GARCH models with dynamic correlations and asymmetric error distributions, Journal of Applied Statistics, 41(2), 320--331, 2014a. <doi:10.1080/02664763.2013.839635>

Fioruci, J.A., Ehlers, R.S., Louzada, F. BayesDccGarch - An Implementation of Multivariate GARCH DCC Models, ArXiv e-prints, 2014b. https://ui.adsabs.harvard.edu/abs/2014arXiv1412.2967F/abstract.

See Also

bayesDccGarch-package, bayesDccGarch

Examples

Run this code

data(DaxCacNik)

Dax = DaxCacNik[,1]

######  log-likelihood function of GARCH(1,1) model with SST innovations ####
logLikDccGarch(Dax, omega=0.03, alpha=0.03, beta=0.8, gamma=0.7)$value

######  log-likelihood function of DCC-GARCH(1,1) model with SST innovations ####
logLikDccGarch(DaxCacNik, beta=c(0.82,0.91,0.85), gamma=c(0.7, 1.3, 1.7), tail=10)$value

Run the code above in your browser using DataLab