Learn R Programming

bayesDccGarch (version 3.0.4)

predict.bayesDccGarch: Bayesian forecast for volatilities and coditional correlations

Description

Bayesian forecast for volatilities and coditional correlations

Usage

# S3 method for bayesDccGarch
predict(object, ..., n_ahead = 5, bayes = T)

Value

A list with elements H and R

Arguments

object

a bayesDccGarch object

...

default argument of predict function, not used

n_ahead

number of steps ahead forecast

bayes

a boolean. If True, then the forecast is calculated as being the average of the forecasts across all states in the Markov chain (much slower). If False then predictions are calculated using estimation parameters (much faster).

References

Engle, R.F. and Sheppard, K. Theoretical and empirical properties of dynamic conditional correlation multivariate GARCH, 2001, NBER Working Paper.

Examples

Run this code
# \donttest{
out = bayesDccGarch(DaxCacNik)
predict.bayesDccGarch(out, n_ahead=5)
# }

Run the code above in your browser using DataLab